{ "natures": [ { "name": "", "FDC ID": "", "UPC": "", "DSLD ID": "" } ], "measures": { "mass + mass equivalents": { "per recipe": { "grams": { "fraction string": "0" } } }, "biological activity": { "per recipe": { "IU": { "fraction string": "0" } } }, "energy": { "per recipe": { "calories": { "fraction string": "0" } } } }, "grove": [ { "essential": { "includes": [], "names": [ "protein" ], "region": 1 }, "measures": { "mass + mass equivalents": { "per recipe": { "grams": { "fraction string": "0" } } } }, "natures": [ { "amount": "1", "source": { "name": "", "FDC ID": "", "UPC": "", "DSLD ID": "" }, "measures": { "mass + mass equivalents": { "per package": { "grams": { "fraction string": "89531560592125469/45035996273704960" } } } } } ], "unites": [] } ] }